@@ -3,9 +3,8 @@
 from .counter_class import Counter
 from .freezing import FrozenDict, FrozenModel, freeze, thaw
 from .lru_cache import LRUCache
-from .priority_queue import PriorityQueue
-from .stacks.simple import SimpleStack
-from .stacks.with_cursor import SimpleStackCursor
+from .queuestuffs import PriorityQueue, SimpooQueue
+from .stacks import SimpleStack, SimpleStackCursor
 
 __all__ = [
     "Counter",
@@ -15,6 +14,7 @@ __all__ = [
     "PriorityQueue",
     "SimpleStack",
     "SimpleStackCursor",
+    "SimpooQueue",
     "freeze",
     "thaw",
 ]
