@@ -1,5 +1,9 @@
+from collections.abc import Generator
+from typing import Any
 from unittest.mock import patch
 
+import pytest
+
 from bear_dereth.platform_utils import (
     DARWIN,
     LINUX,
@@ -11,6 +15,13 @@ from bear_dereth.platform_utils import (
 )
 
 
+@pytest.fixture(autouse=True)
+def clear_platform_cache() -> Generator[None, Any]:
+    get_platform.cache_clear()  # Clear the cache before each test
+    yield
+    get_platform.cache_clear()  # Clear the cache after each test
+
+
 @patch("platform.system", return_value="Darwin")
 def test_macos(mock_system):
     assert get_platform() == DARWIN
@@ -20,7 +31,7 @@ def test_macos(mock_system):
 
 
 @patch("platform.system", return_value="Windows")
-def test_windows(mock_system):
+def test_windows(mock_system) -> None:
     assert get_platform() == WINDOWS
     assert is_windows()
     assert not is_macos()
@@ -28,7 +39,7 @@ def test_windows(mock_system):
 
 
 @patch("platform.system", return_value="Linux")
-def test_linux(mock_system):
+def test_linux(mock_system) -> None:
     assert get_platform() == LINUX
     assert is_linux()
     assert not is_macos()
@@ -36,7 +47,7 @@ def test_linux(mock_system):
 
 
 @patch("platform.system", return_value="FakeOS")
-def test_other(mock_system):
+def test_other(mock_system) -> None:
     assert get_platform() == "Other"
     assert not is_macos()
     assert not is_windows()
